@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: edit.php,v 1.7 2006/03/26 17:51:25 gruberroland Exp $
+$Id: edit.php,v 1.9 2006/09/16 13:26:18 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003 - 2006  Tilo Lutz
@@ -62,7 +62,19 @@ if (isset($_GET['DN'])) {
 	if ($_GET['type'] == $type) $type = str_replace("'", '',$_GET['type']);
 	if ($_GET['DN'] == $DN) $DN = str_replace("'", '',$_GET['DN']);
 	$_SESSION['account'] = new accountContainer($type, 'account');
-	$_SESSION['account']->load_account($DN);
+	$result = $_SESSION['account']->load_account($DN);
+	if (sizeof($result) > 0) {
+		echo $_SESSION['header'];
+		echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/layout.css\">\n";
+		echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/type_" . $type . ".css\">\n";
+		echo "</head><body>\n";
+		for ($i=0; $i<sizeof($result); $i++) {
+			call_user_func_array("StatusMessage", $result[$i]);
+		}
+		echo "</body>\n";
+		echo "</html>\n";
+		die();
+	}
 }
 // new account
 else if (count($_POST)==0) {
@@ -81,6 +93,6 @@ if (get_magic_quotes_gpc() == 1) {
 }
 
 // show account page
-$_SESSION['account']->continue_main($_POST);
+$_SESSION['account']->continue_main();
 
 ?>
