@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: conflogin.php,v 1.39 2006/04/16 12:44:18 gruberroland Exp $
+$Id: conflogin.php,v 1.40 2006/09/24 14:19:50 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003 - 2006  Roland Gruber
@@ -110,7 +110,7 @@ echo $_SESSION['header'];
 					<?php
 						if (sizeof($files) > 0) {
 							echo "<select size=1 name=\"filename\">\n";
-							$conf = new CfgMain();
+							$conf = new LAMCfgMain();
 							$defaultprofile = $conf->default;
 							for ($i = 0; $i < sizeof($files); $i++) {
 								if ($files[$i] == $defaultprofile) echo ("<option selected>" . $files[$i] . "</option>\n");
