@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: confmain.php,v 1.85 2007/03/05 17:05:38 gruberroland Exp $
+$Id: confmain.php,v 1.88 2007/10/26 17:51:56 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003 - 2007  Roland Gruber
@@ -125,6 +125,11 @@ echo ("<body>\n");
 echo ("<p align=\"center\"><a href=\"http://lam.sourceforge.net\" target=\"new_window\">".
 	"<img src=\"../../graphics/banner.jpg\" border=1 alt=\"LDAP Account Manager\"></a></p>\n<hr>\n<p></p>\n");
 
+if (!$conf->isWritable()) {
+	StatusMessage('WARN', 'The config file is not writable.', 'Your changes cannot be saved until you make the file writable for the webserver user.');
+	echo "<br>";
+}
+
 // display error messages
 if (isset($_SESSION['conf_errors'])) {
 	for ($i = 0; $i < sizeof($_SESSION['conf_errors']); $i++) {
@@ -247,7 +252,7 @@ echo ("<table border=0>\n");
 
 // maximum list entries
 echo ("<tr><td align=\"right\"><b>".
-	_("Maximum list entries") . " : </b></td>".
+	_("Maximum list entries") . ": </b></td>".
 	"<td><select tabindex=\"$tabindex\" name=\"maxlistentries\">\n<option selected>".$conf->get_MaxListEntries()."</option>\n");
 if ($conf->get_MaxListEntries() != 10) echo("<option>10</option>\n");
 if ($conf->get_MaxListEntries() != 20) echo("<option>20</option>\n");
@@ -502,15 +507,15 @@ function saveSettings() {
 	$chmodOwner = 0;
 	$chmodGroup = 0;
 	$chmodOther = 0;
-	if ($_POST['chmod_owr'] == 'on') $chmodOwner += 4;
-	if ($_POST['chmod_oww'] == 'on') $chmodOwner += 2;
-	if ($_POST['chmod_owe'] == 'on') $chmodOwner += 1;
-	if ($_POST['chmod_grr'] == 'on') $chmodGroup += 4;
-	if ($_POST['chmod_grw'] == 'on') $chmodGroup += 2;
-	if ($_POST['chmod_gre'] == 'on') $chmodGroup += 1;
-	if ($_POST['chmod_otr'] == 'on') $chmodOther += 4;
-	if ($_POST['chmod_otw'] == 'on') $chmodOther += 2;
-	if ($_POST['chmod_ote'] == 'on') $chmodOther += 1;
+	if (isset($_POST['chmod_owr']) && ($_POST['chmod_owr'] == 'on')) $chmodOwner += 4;
+	if (isset($_POST['chmod_oww']) && ($_POST['chmod_oww'] == 'on')) $chmodOwner += 2;
+	if (isset($_POST['chmod_owe']) && ($_POST['chmod_owe'] == 'on')) $chmodOwner += 1;
+	if (isset($_POST['chmod_grr']) && ($_POST['chmod_grr'] == 'on')) $chmodGroup += 4;
+	if (isset($_POST['chmod_grw']) && ($_POST['chmod_grw'] == 'on')) $chmodGroup += 2;
+	if (isset($_POST['chmod_gre']) && ($_POST['chmod_gre'] == 'on')) $chmodGroup += 1;
+	if (isset($_POST['chmod_otr']) && ($_POST['chmod_otr'] == 'on')) $chmodOther += 4;
+	if (isset($_POST['chmod_otw']) && ($_POST['chmod_otw'] == 'on')) $chmodOther += 2;
+	if (isset($_POST['chmod_ote']) && ($_POST['chmod_ote'] == 'on')) $chmodOther += 1;
 	$chmod = $chmodOwner . $chmodGroup . $chmodOther;
 	if (!$conf->set_scriptrights($chmod)) {
 		$errors[] = array("ERROR", _("Script rights are invalid!"));
