@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: mainlogin.php,v 1.2 2006/04/18 10:54:49 gruberroland Exp $
+$Id: mainlogin.php,v 1.3 2006/09/24 14:19:50 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003 - 2006  Roland Gruber
@@ -46,7 +46,7 @@ if (isset($_SESSION["mainconf_password"])) unset($_SESSION["mainconf_password"])
 
 // check if user entered a password
 if (isset($_POST['passwd'])) {
-	$cfgMain = new CfgMain();
+	$cfgMain = new LAMCfgMain();
 	if (isset($_POST['passwd']) && ($_POST['passwd'] == $cfgMain->password)) {
 		$_SESSION["mainconf_password"] = $_POST['passwd'];
 		metaRefresh("mainmanage.php");
