@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: profmanage.php,v 1.21 2006/05/13 16:52:45 gruberroland Exp $
+$Id: profmanage.php,v 1.23 2006/09/24 14:19:50 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003 - 2006  Roland Gruber
@@ -21,7 +21,7 @@ $Id: profmanage.php,v 1.21 2006/05/13 16:52:45 gruberroland Exp $
 
 */
 
-  
+
 /**
 * Configuration profile management.
 *
@@ -60,7 +60,7 @@ echo $_SESSION['header'];
 
 <?php
 
-$cfg = new CfgMain();
+$cfg = new LAMCfgMain();
 // check if submit button was pressed
 if ($_POST['submit']) {
 	// check master password
@@ -69,7 +69,7 @@ if ($_POST['submit']) {
 	}
 	// add new profile
 	elseif ($_POST['action'] == "add") {
-		if (eregi("^[a-z0-9\-_]+$", $_POST['addprofile']) && !in_array($_POST['addprofile'], getConfigProfiles())) {
+		if (eregi("^[a-z0-9_-]+$", $_POST['addprofile']) && !in_array($_POST['addprofile'], getConfigProfiles())) {
 			// check profile password
 			if ($_POST['addpassword'] && $_POST['addpassword2'] && ($_POST['addpassword'] == $_POST['addpassword2'])) {
 				// create new profile file
@@ -78,7 +78,7 @@ if ($_POST['submit']) {
 				$file = is_file("../../config/" . $_POST['addprofile'] . ".conf");
 				if ($file) {
 					// load as config and write new password
-					$conf = new Config($_POST['addprofile']);
+					$conf = new LAMConfig($_POST['addprofile']);
 					$conf->Passwd = $_POST['addpassword'];
 					$conf->save();
 					$msg = _("Created new profile.");
@@ -91,7 +91,7 @@ if ($_POST['submit']) {
 	}
 	// rename profile
 	elseif ($_POST['action'] == "rename") {
-		if (eregi("^[a-z0-9\-_]+$", $_POST['renfilename']) && !in_array($_POST['renprofile'], getConfigProfiles())) {
+		if (eregi("^[a-z0-9_-]+$", $_POST['renfilename']) && !in_array($_POST['renfilename'], getConfigProfiles())) {
 			if (rename("../../config/" . $_POST['oldfilename'] . ".conf",
 				"../../config/" . $_POST['renfilename'] . ".conf")) {
 				$msg = _("Renamed profile.");
@@ -102,7 +102,7 @@ if ($_POST['submit']) {
 	}
 	// delete profile
 	elseif ($_POST['action'] == "delete") {
-		if (@unlink("../../config/" . $_POST['delfilename'] . ".conf")) {
+		if (eregi("^[a-z0-9_-]+$", $_POST['delfilename']) && @unlink("../../config/" . $_POST['delfilename'] . ".conf")) {
 			$msg = _("Profile deleted.");
 		}
 		else $error = _("Unable to delete profile!");
@@ -110,7 +110,7 @@ if ($_POST['submit']) {
 	// set new profile password
 	elseif ($_POST['action'] == "setpass") {
 		if ($_POST['setpassword'] && $_POST['setpassword2'] && ($_POST['setpassword'] == $_POST['setpassword2'])) {
-			$config = new Config($_POST['setprofile']);
+			$config = new LAMConfig($_POST['setprofile']);
 			$config->set_Passwd($_POST['setpassword']);
 			$config->save();
 			$msg = _("New password set successfully.");
@@ -119,15 +119,15 @@ if ($_POST['submit']) {
 	}
 	// set default profile
 	elseif ($_POST['action'] == "setdefault") {
-		$config = new CfgMain();
+		$config = new LAMCfgMain();
 		$config->default = $_POST['defaultfilename'];
 		$config->save();
 		$msg = _("New default profile set successfully.");
 	}
 	// print messages
 	if ($error || $msg) {
-		if ($error) StatusMessage("ERROR", "", $error);
-		if ($msg) StatusMessage("INFO", "", $msg);
+		if ($error) StatusMessage("ERROR", $error);
+		if ($msg) StatusMessage("INFO", $msg);
 	}
 	else exit;
 }
@@ -314,7 +314,7 @@ if (!isset($cfg->default) && !isset($cfg->password)) {
 						<select size=1 name="defaultfilename">
 						<?php
 							$files = getConfigProfiles();
-							$conf = new CfgMain();
+							$conf = new LAMCfgMain();
 							$defaultprofile = $conf->default;
 							for ($i = 0; $i < sizeof($files); $i++) {
 								if ($files[$i] == $defaultprofile) echo ("<option selected>" . $files[$i] . "</option>\n");
