@@ -1,6 +1,6 @@
 <?php
 /*
-	$Id: delete.php,v 1.60 2007/02/25 13:51:40 gruberroland Exp $
+	$Id: delete.php,v 1.63 2007/10/26 14:09:20 gruberroland Exp $
 
 	This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
 	Copyright (C) 2003 - 2006  Tilo Lutz
@@ -61,7 +61,7 @@ setlanguage();
 if (!isset($_SESSION['cache'])) {
 	$_SESSION['cache'] = new cache();
 }
-if ($_GET['type']) {
+if (isset($_GET['type']) && isset($_SESSION['delete_dn'])) {
 	// Create account list
 	foreach ($_SESSION['delete_dn'] as $dn) {
 		$start = strpos ($dn, "=")+1;
@@ -140,13 +140,14 @@ if ($_POST['delete']) {
 		// First load DN.
 		$_SESSION['account']->load_account($_SESSION['delete_dn'][$m]);
 		// get commands and changes of each attribute
-		$module = array_keys($_SESSION['account']->module);
+		$moduleNames = array_keys($_SESSION['account']->getAccountModules());
+		$modules = $_SESSION['account']->getAccountModules();
 		$attributes = array();
 		$errors = array();
 		// predelete actions
 		if (!$stopprocessing) {
-			foreach ($module as $singlemodule) {
-				$success = $_SESSION['account']->module[$singlemodule]->preDeleteActions();
+			foreach ($moduleNames as $singlemodule) {
+				$success = $modules[$singlemodule]->preDeleteActions();
 				if (!$success) {
 					$stopprocessing = true;
 					break;
@@ -155,9 +156,9 @@ if ($_POST['delete']) {
 		}		
 		if (!$stopprocessing) {
 			// load attributes
-			foreach ($module as $singlemodule) {
+			foreach ($moduleNames as $singlemodule) {
 				// load changes
-				$temp = $_SESSION['account']->module[$singlemodule]->delete_attributes();
+				$temp = $modules[$singlemodule]->delete_attributes();
 				if (is_array($temp)) {
 					// merge changes
 					$DNs = array_keys($temp);
@@ -215,8 +216,8 @@ if ($_POST['delete']) {
 		}
 		// post delete actions
 		if (!$stopprocessing) {
-			foreach ($module as $singlemodule) {
-				$_SESSION['account']->module[$singlemodule]->postDeleteActions();
+			foreach ($moduleNames as $singlemodule) {
+				$modules[$singlemodule]->postDeleteActions();
 			}
 		}		
 		if (!$stopprocessing) {
@@ -248,9 +249,9 @@ if ($_POST['delete']) {
 */
 function getChildCount($dn) {
 	$return = 0;
-	$sr = @ldap_search($_SESSION['ldap']->server, $dn, 'objectClass=*', array('dn'), 0);
+	$sr = @ldap_search($_SESSION['ldap']->server(), $dn, 'objectClass=*', array('dn'), 0);
 	if ($sr) {
-		$entries = ldap_get_entries($_SESSION['ldap']->server, $sr);
+		$entries = ldap_get_entries($_SESSION['ldap']->server(), $sr);
 		$return = $entries['count'] - 1;
 	}
 	return $return;
@@ -264,9 +265,9 @@ function getChildCount($dn) {
 */
 function deleteDN($dn) {
 	$errors = array();
-	$sr = @ldap_list($_SESSION['ldap']->server, $dn, 'objectClass=*', array('dn'), 0);
+	$sr = @ldap_list($_SESSION['ldap']->server(), $dn, 'objectClass=*', array('dn'), 0);
 	if ($sr) {
-		$entries = ldap_get_entries($_SESSION['ldap']->server, $sr);
+		$entries = ldap_get_entries($_SESSION['ldap']->server(), $sr);
 		for ($i = 0; $i < $entries['count']; $i++) {
 			// delete recursively
 			$subErrors = deleteDN($entries[$i]['dn']);
