@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: login.php,v 1.98 2007/02/11 13:55:03 gruberroland Exp $
+$Id: login.php,v 1.104 2007/11/03 11:20:52 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003 - 2006  Michael Duergner
@@ -53,6 +53,10 @@ if (! function_exists('gettext') || !function_exists('_')) {
 if (! function_exists('utf8_decode')) {
 	$criticalErrors[] = array("ERROR", "Your PHP has no XML support!", "Please install the XML extension for PHP.");
 }
+// check if PHP >= 5.1
+if (version_compare(phpversion(), '5.1.0') < 0) {
+	$criticalErrors[] = array("ERROR", "LAM needs PHP 5 greater or equal as 5.1.0!", "Please upgrade your PHP installation.");
+}
 // check file permissions
 $writableDirs = array('sess', 'tmp');
 for ($i = 0; $i < sizeof($writableDirs); $i++) {
@@ -65,6 +69,13 @@ for ($i = 0; $i < sizeof($writableDirs); $i++) {
 if (ini_get("session.auto_start") == "1") {
 	$criticalErrors[] = array("ERROR", "Please deactivate session.auto_start in your php.ini. LAM will not work if it is activated.");
 }
+$memLimit = ini_get('memory_limit');
+if (isset($memLimit) && ($memLimit != '') && (substr(strtoupper($memLimit), strlen($memLimit) - 1) == 'M')) {
+	if (intval(substr($memLimit, 0, strlen($memLimit) - 1)) < 64) {
+		$criticalErrors[] = array("ERROR", "Please increase the \"memory_limit\" parameter in your php.ini to at least \"64M\".",
+			"Your current memory limit is $memLimit.");	
+	}
+}
 // stop login if critical errors occured
 if (sizeof($criticalErrors) > 0) {
 	echo "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
@@ -397,7 +408,8 @@ if(!empty($_POST['checklogin']))
 			// logging
 			logNewMessage(LOG_NOTICE, 'User ' . $_POST['username'] . ' successfully logged in.');
 			// Load main frame
-			include("./main.php");
+			metaRefresh("./main.php");
+			die();
 		}
 		else
 		{
