@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: main.php,v 1.33 2006/05/21 15:25:44 gruberroland Exp $
+$Id: main.php,v 1.36 2007/07/08 10:49:06 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003 - 2006  Roland Gruber
@@ -30,6 +30,13 @@ $Id: main.php,v 1.33 2006/05/21 15:25:44 gruberroland Exp $
 
 /** LDAP attibute cache */
 include_once('../lib/cache.inc');
+/** config object */
+include_once('../lib/config.inc');
+
+// start session
+startSecureSession();
+
+setlanguage();
 
 // create cache object
 if (!isset($_SESSION['cache'])) {
@@ -42,8 +49,8 @@ $new_suffs = array();
 // get list of active types
 $types = $_SESSION['config']->get_ActiveTypes();
 for ($i = 0; $i < sizeof($types); $i++) {
-	$info = @ldap_search($_SESSION['ldap']->server, $conf->get_Suffix($types[$i]), "(objectClass=*)", array());
-	$res = @ldap_get_entries($_SESSION['ldap']->server, $info);
+	$info = @ldap_search($_SESSION['ldap']->server(), $conf->get_Suffix($types[$i]), "(objectClass=*)", array('objectClass'));
+	$res = @ldap_get_entries($_SESSION['ldap']->server(), $info);
 	if (!$res && !in_array($conf->get_Suffix($types[$i]), $new_suffs)) $new_suffs[] = $conf->get_Suffix($types[$i]);
 }
 
