@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: massBuildAccounts.php,v 1.9 2005/06/03 11:54:08 gruberroland Exp $
+$Id: massBuildAccounts.php,v 1.11 2006/03/26 17:51:25 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
-  Copyright (C) 2004  Roland Gruber
+  Copyright (C) 2004 - 2006  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,6 +28,8 @@ $Id: massBuildAccounts.php,v 1.9 2005/06/03 11:54:08 gruberroland Exp $
 * @package tools
 */
 
+/** security functions */
+include_once("../lib/security.inc");
 /** access to configuration */
 include_once('../lib/config.inc');
 /** status messages */
@@ -37,8 +39,7 @@ include_once('../lib/modules.inc');
 
 
 // Start session
-session_save_path('../sess');
-@session_start();
+startSecureSession();
 
 // Redirect to startpage if user is not loged in
 if (!isset($_SESSION['loggedIn'])) {
