@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: masscreate.php,v 1.70 2006/03/26 17:51:25 gruberroland Exp $
+$Id: masscreate.php,v 1.71 2007/06/10 14:47:43 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2004 - 2006  Roland Gruber
@@ -156,7 +156,7 @@ function showMainPage($scope) {
 			echo "<br>\n";
 				echo "<ul>\n";
 					echo "<li><b>" . _("Identifier") . ":</b> " . "dn_suffix</li>\n";
-					echo "<li><b>" . _("Example value") . ":</b> " . "ou=accounts,dc=yourdomain,dc=org</li>\n";
+					echo "<li><b>" . _("Example value") . ":</b> " . _("ou=accounts,dc=yourdomain,dc=org") . "</li>\n";
 					echo "<li><b>" . _("Default value") . ":</b> " . $_SESSION['config']->get_Suffix($scope) . "</li>\n";
 				echo "</ul>\n";
 			echo "</td>\n";
