@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: profilemain.php,v 1.22 2004/12/12 11:27:57 gruberroland Exp $
+$Id: profilemain.php,v 1.27 2006/03/26 17:51:25 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
-  Copyright (C) 2003  Roland Gruber
+  Copyright (C) 2003 - 2006  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,6 +28,8 @@ $Id: profilemain.php,v 1.22 2004/12/12 11:27:57 gruberroland Exp $
 * @author Roland Gruber
 */
 
+/** security functions */
+include_once("../../lib/security.inc");
 /** helper functions for profiles */
 include_once("../../lib/profiles.inc");
 /** access to LDAP server */
@@ -36,16 +38,19 @@ include_once("../../lib/ldap.inc");
 include_once("../../lib/config.inc");
 
 // start session
-session_save_path("../../sess");
-@session_start();
+startSecureSession();
 
 setlanguage();
 
-$profileClasses = array(
-	array('scope' => 'user', 'title' => _('User profiles'), 'profiles' => ""),
-	array('scope' => 'group', 'title' => _('Group profiles'), 'profiles' => ""),
-	array('scope' => 'host', 'title' => _('Host profiles'), 'profiles' => "")
-);
+$types = $_SESSION['config']->get_ActiveTypes();
+$profileClasses = array();
+for ($i = 0; $i < sizeof($types); $i++) {
+	$profileClasses[] = array(
+		'scope' => $types[$i],
+		'title' => getTypeAlias($types[$i]),
+		'profiles' => "");
+}
+
 
 // check if user is logged in, if not go to login
 if (!$_SESSION['ldap'] || !$_SESSION['ldap']->server()) {
@@ -53,14 +58,15 @@ if (!$_SESSION['ldap'] || !$_SESSION['ldap']->server()) {
 	exit;
 }
 
-// check if user has pressed submit or abort button
-if ($_POST['submit']) {
-	// on abort go back to main page
-	if ($_POST['abort']) {
-		metaRefresh("../lists/listusers.php");
-	}
-	// on submit forward to other profile pages
-	elseif ($_POST['submit']) {
+// on abort go back to main page
+if (isset($_POST['abort'])) {
+	metaRefresh("../tools.php");
+	exit;
+}
+// check if user has pressed submit button
+elseif (isset($_POST['submit'])) {
+	// forward to other profile pages
+	if ($_POST['submit']) {
 		for ($i = 0; $i < sizeof($profileClasses); $i++) {
 			// create new profile
 			if ($_POST['profile'] == ("new" . $profileClasses[$i]['scope'])) {
@@ -96,6 +102,9 @@ echo $_SESSION['header'];
 
 echo "<title>LDAP Account Manager</title>\n";
 echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/layout.css\">\n";
+for ($i = 0; $i < sizeof($profileClasses); $i++) {
+	echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/type_" . $profileClasses[$i]['scope'] . ".css\">\n";
+}
 echo "</head>\n";
 echo "<body>\n";
 
@@ -105,7 +114,7 @@ echo "<form action=\"profilemain.php\" method=\"post\">\n";
 
 for ($i = 0; $i < sizeof($profileClasses); $i++) {
 
-	echo "<fieldset>\n";
+	echo "<fieldset class=\"" . $profileClasses[$i]['scope'] . "edit\">\n";
 	echo "<legend>\n";
 	echo "<b>" . $profileClasses[$i]['title'] . "</b>\n";
 	echo "</legend>\n";
@@ -153,8 +162,8 @@ for ($i = 0; $i < sizeof($profileClasses); $i++) {
 
 
 echo "<p>\n";
-echo "<input type=\"submit\" name=\"submit\" value=\"" . _("Submit") . "\">\n";
-echo "<input type=\"submit\" name=\"abort\" value=\"" . _("Abort") . "\">\n";
+echo "<input type=\"submit\" name=\"submit\" value=\"" . _("Ok") . "\">\n";
+echo "<input type=\"submit\" name=\"abort\" value=\"" . _("Cancel") . "\">\n";
 echo "</p>\n";
 
 echo "</form>\n";
