@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: lamdaemonTest.php,v 1.5 2007/02/22 17:38:22 gruberroland Exp $
+$Id: lamdaemonTest.php,v 1.6 2007/06/07 14:27:11 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2006 - 2007  Roland Gruber
@@ -87,7 +87,10 @@ function lamTestLamdaemon($command, $stopTest, $handle, $testText) {
 		}
 		$errOut = @fread($stderr, 100000);
 		if ((strpos(strtolower($errOut), "sudoers") !== false) || (strpos(strtolower($errOut), "sorry") !== false)) {
-			$return[] = "ERROR," . _("Sudo is not setup correctly!") . "," . str_replace(",", " ", $errOut);
+			$return[] = "ERROR," . _("Sudo is not setup correctly!") . "," . htmlspecialchars(str_replace(",", " ", $errOut));
+		}
+		elseif (strlen($errOut) > 0) {
+			$return[] = "ERROR," . _("Unknown error") . "," . htmlspecialchars(str_replace(",", " ", $errOut));
 		}
 		if ((sizeof($return) == 1) && (strpos(strtolower($return[0]), "error") === false)) {
 			$lamdaemonOk = true;
