@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: add_attr.php,v 1.2 2006/03/26 17:51:25 gruberroland Exp $
+$Id: add_attr.php,v 1.3 2007/07/08 10:49:06 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   
@@ -115,7 +115,7 @@ elseif (0 == strcasecmp( $attr , 'sambantpassword' )) {
 	$val = ntPassword($val);
 }
 
-$ds = $_SESSION['ldap']->server;
+$ds = $_SESSION['ldap']->server();
 $new_entry = array( $attr => $val );
 $result = @ldap_mod_add( $ds, $dn, $new_entry );
 
