@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: add_oclass.php,v 1.3 2006/03/26 17:51:25 gruberroland Exp $
+$Id: add_oclass.php,v 1.4 2007/07/08 10:49:06 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   
@@ -77,7 +77,7 @@ if( is_array( $new_attrs ) && count( $new_attrs ) > 0 )
 		$new_entry[ $attr ] = $val;
 	}
 
-$ds = $_SESSION['ldap']->server;
+$ds = $_SESSION['ldap']->server();
 $add_res = @ldap_mod_add( $ds, $dn, $new_entry );
 
 if( ! $add_res )
