@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: add_oclass_form.php,v 1.3 2006/03/26 17:51:25 gruberroland Exp $
+$Id: add_oclass_form.php,v 1.4 2007/07/08 10:49:06 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   
@@ -148,7 +148,7 @@ if( count( $needed_attrs ) > 0 )
 }
 else
 {
-	$ds = $_SESSION['ldap']->server;
+	$ds = $_SESSION['ldap']->server();
 	$add_res = @ldap_mod_add( $ds, $dn, array( 'objectClass' => $new_oclass ) );
 	if( ! $add_res ) {
 		echo $_SESSION['header'];
