@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: add_value.php,v 1.2 2006/03/26 17:51:25 gruberroland Exp $
+$Id: add_value.php,v 1.3 2007/07/08 10:49:06 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   
@@ -68,7 +68,7 @@ $encoded_attr = rawurlencode( $attr );
 $new_value = $_POST['new_value'];
 $is_binary_val = isset( $_POST['binary'] ) ? true : false;
 
-$ds = $_SESSION['ldap']->server;
+$ds = $_SESSION['ldap']->server();
 
 // special case for binary attributes: 
 // we must go read the data from the file.
