@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: create.php,v 1.2 2006/03/26 17:51:25 gruberroland Exp $
+$Id: create.php,v 1.3 2007/07/08 10:49:06 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   
@@ -126,7 +126,7 @@ foreach( $new_entry as $attr => $vals ) {
 
 //echo "<pre>"; var_dump( $new_dn );print_r( $new_entry ); echo "</pre>";
 
-$ds = $_SESSION['ldap']->server;
+$ds = $_SESSION['ldap']->server();
 
 // Check the user-defined custom call back first
 $add_result = @ldap_add( $ds, $new_dn, $new_entry );
