@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: delete.php,v 1.2 2006/03/26 17:51:25 gruberroland Exp $
+$Id: delete.php,v 1.3 2007/07/08 10:49:07 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   
@@ -66,7 +66,7 @@ echo "<body>";
 $dn = $_POST['dn'];
 $encoded_dn = rawurlencode( $dn );
 
-$ds = $_SESSION['ldap']->server;
+$ds = $_SESSION['ldap']->server();
 
 $del_result = @ldap_delete( $ds, $dn );
 
