@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: delete_attr.php,v 1.2 2006/03/26 17:51:25 gruberroland Exp $
+$Id: delete_attr.php,v 1.3 2007/07/08 10:49:07 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   
@@ -62,7 +62,7 @@ $attr = $_POST['attr'];
 
 $update_array = array();
 $update_array[$attr] = array();
-$ds = $_SESSION['ldap']->server;
+$ds = $_SESSION['ldap']->server();
 $res = @ldap_modify( $ds, $dn, $update_array );
 if( $res ) {
 	$redirect_url = "edit.php?dn=$encoded_dn";
