@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: update.php,v 1.2 2006/03/26 17:51:25 gruberroland Exp $
+$Id: update.php,v 1.3 2007/07/08 10:49:07 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   
@@ -86,7 +86,7 @@ foreach( $update_array as $attr => $val )
 		}
 	}
 			
-$ds = $_SESSION['ldap']->server;
+$ds = $_SESSION['ldap']->server();
 $res = @ldap_modify( $ds, $dn, $update_array );
 if( $res )
 {
